pub struct Header {
pub var_count: usize,
pub clause_count: usize,
}Expand description
Header data of a DIMACS CNF file.
Contains the number of variables and clauses. This parser considers a count of 0 as
unspecified and will not check that count during parsing, even in strict mode.
Fields
var_count: usizeUpper bound on the number of variables present in the formula.
Ignored during parsing when 0.
clause_count: usizeNumber of clauses present in the formula.
Ignored during parsing when 0.